@@ -4,11 +4,11 @@
 
 ## no critic (Modules::RequireExplicitPackage)
 # 'use strict' and 'use warnings' included here
-use Modern::Perl qw(2018); # require 5.26 security update
+use Modern::Perl qw(2015); # require 5.20.0
 ## use critic (Modules::RequireExplicitPackage)
 
 package Container::Buildah;
-$Container::Buildah::VERSION = '0.2.0';
+$Container::Buildah::VERSION = '0.2.1';
 use autodie;
 use Carp qw(croak confess);
 use Exporter;
@@ -613,7 +613,7 @@ Container::Buildah - wrapper around containers/buildah tool for multi-stage buil
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 SYNOPSIS
 
