@@ -4,11 +4,11 @@
 
 ## no critic (Modules::RequireExplicitPackage)
 # 'use strict' and 'use warnings' included here
-use Modern::Perl qw(2018); # require 5.26 security update
+use Modern::Perl qw(2015); # require 5.20.0
 ## use critic (Modules::RequireExplicitPackage)
 
 package Container::Buildah::Stage;
-$Container::Buildah::Stage::VERSION = '0.2.0';
+$Container::Buildah::Stage::VERSION = '0.2.1';
 use autodie;
 use Carp qw(croak confess);
 use Cwd;
@@ -647,7 +647,7 @@ Container::Buildah::Stage - object used by Container::Buildah to track a stage o
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 SYNOPSIS
 
